import { HttpClient, EventDefinition, MaybeContext, BuildRESTFunction, BuildEventDefinition } from '@wix/sdk-types';
import { B as BillableItem, U as UpdateBillableItem, a as BillableItemsQueryBuilder, b as BulkCreateBillableItemsOptions, c as BulkCreateBillableItemsResponse, M as MaskedBillableItem, d as BulkUpdateBillableItemsOptions, e as BulkUpdateBillableItemsResponse, f as BulkDeleteBillableItemsResponse, g as BulkUpdateBillableItemTagsOptions, V as V1BulkUpdateBillableItemTagsResponse, h as BulkUpdateBillableItemTagsByFilterOptions, i as V1BulkUpdateBillableItemTagsByFilterResponse, j as BillableItemSearch, S as SearchBillableItemsResponse, k as BillableItemCreatedEnvelope, l as BillableItemDeletedEnvelope, m as BillableItemUpdatedEnvelope } from './billable-items-v1-billable-item-billable-items.universal-CWG6mEYe.js';
export { L as ActionEvent, as as Aggregation, aG as AggregationData, at as AggregationKindOneOf, aZ as AggregationResults, a_ as AggregationResultsResultOneOf, aN as AggregationResultsScalarResult, A as AggregationType, x as ApplicationError, a$ as BaseEventMetadata, b2 as BillableItemSearchSpec, b1 as BillableItemsQueryResult, z as BulkActionMetadata, ah as BulkBillableItemResult, ag as BulkCreateBillableItemsRequest, ak as BulkDeleteBillableItemsRequest, al as BulkDeleteBillableItemsResponseBulkBillableItemResult, C as BulkUpdateBillableItemTagsByFilterRequest, D as BulkUpdateBillableItemTagsByFilterResponse, u as BulkUpdateBillableItemTagsRequest, v as BulkUpdateBillableItemTagsResponse, an as BulkUpdateBillableItemTagsResponseBulkUpdateBillableItemTagsResult, y as BulkUpdateBillableItemTagsResult, ai as BulkUpdateBillableItemsRequest, aj as BulkUpdateBillableItemsResponseBulkBillableItemResult, X as CreateBillableItemRequest, Y as CreateBillableItemResponse, a7 as CursorPaging, a9 as CursorPagingMetadata, a4 as CursorQuery, a5 as CursorQueryPagingMethodOneOf, aq as CursorSearch, ar as CursorSearchPagingMethodOneOf, aa as Cursors, aA as DateHistogramAggregation, aV as DateHistogramResult, aX as DateHistogramResults, a1 as DeleteBillableItemRequest, a2 as DeleteBillableItemResponse, F as DomainEvent, G as DomainEventBodyOneOf, H as EntityCreatedEvent, K as EntityDeletedEvent, J as EntityUpdatedEvent, b0 as EventMetadata, E as ExtendedFields, Z as GetBillableItemRequest, _ as GetBillableItemResponse, aW as GroupByValueResults, P as IdentificationData, Q as IdentificationDataIdOneOf, av as IncludeMissingValuesOptions, ae as InternalCursorPaging, ac as InternalCursorQuery, ad as InternalCursorQueryPagingMethodOneOf, ab as InternalQueryBillableItemsRequest, af as InternalQueryBillableItemsResponse, I as Interval, w as ItemMetadata, O as MessageEnvelope, q as MissingValues, s as Mode, aD as NestedAggregation, aB as NestedAggregationItem, aC as NestedAggregationItemKindOneOf, aJ as NestedAggregationResults, aK as NestedAggregationResultsResultOneOf, N as NestedAggregationType, aS as NestedResultValue, aT as NestedResultValueResultOneOf, aY as NestedResults, aO as NestedValueAggregationResult, aF as PagingMetadataV2, a3 as QueryBillableItemsRequest, a8 as QueryBillableItemsResponse, ay as RangeAggregation, aI as RangeAggregationResult, au as RangeBucket, aQ as RangeResult, aM as RangeResults, R as RestoreInfo, aU as Results, az as ScalarAggregation, aR as ScalarResult, r as ScalarType, ap as SearchBillableItemsRequest, aE as SearchDetails, p as SortDirection, n as SortOrder, o as SortType, a6 as Sorting, t as TagList, T as Tags, $ as UpdateBillableItemRequest, a0 as UpdateBillableItemResponse, ao as V1BulkUpdateBillableItemTagsByFilterRequest, am as V1BulkUpdateBillableItemTagsRequest, aw as ValueAggregation, ax as ValueAggregationOptionsOneOf, aH as ValueAggregationResult, aP as ValueResult, aL as ValueResults, W as WebhookIdentityType } from './billable-items-v1-billable-item-billable-items.universal-CWG6mEYe.js';

declare function createBillableItem$1(httpClient: HttpClient): CreateBillableItemSignature;
interface CreateBillableItemSignature {
    /**
     * Creates a billable item.
     * @param - BillableItem to be created.
     * @returns The created BillableItem.
     */
    (billableItem: BillableItem): Promise<BillableItem>;
}
declare function getBillableItem$1(httpClient: HttpClient): GetBillableItemSignature;
interface GetBillableItemSignature {
    /**
     * Retrieves a billable item.
     * @param - Billable item ID.
     * @returns Requested billable item.
     */
    (billableItemId: string): Promise<BillableItem>;
}
declare function updateBillableItem$1(httpClient: HttpClient): UpdateBillableItemSignature;
interface UpdateBillableItemSignature {
    /**
     * Updates a billable item.
     *
     *
     * Each time the BillableItem is updated,
     * `revision` increments by 1.
     * The current `revision` must be passed when updating the billable item.
     * This ensures you're working with the latest billable item
     * and prevents unintended overwrites.
     * @param - Billable item ID.
     * @returns Updated billable item.
     */
    (_id: string, billableItem: UpdateBillableItem): Promise<BillableItem>;
}
declare function deleteBillableItem$1(httpClient: HttpClient): DeleteBillableItemSignature;
interface DeleteBillableItemSignature {
    /**
     * Permanently deletes a billable item.
     * @param - Billable item ID to delete.
     */
    (billableItemId: string): Promise<void>;
}
declare function queryBillableItems$1(httpClient: HttpClient): QueryBillableItemsSignature;
interface QueryBillableItemsSignature {
    /**
     * Retrieves a list of BillableItems, given the provided [paging, filtering, and sorting](https://dev.wix.com/api/rest/getting-started/sorting-and-paging).
     *
     * Up to 1,000 BillableItems can be returned per request.
     *
     * To learn how to query BillableItems, see [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language).
     */
    (): BillableItemsQueryBuilder;
}
declare function bulkCreateBillableItems$1(httpClient: HttpClient): BulkCreateBillableItemsSignature;
interface BulkCreateBillableItemsSignature {
    /**
     * Create multiple billable items.
     * @param - List of billable items to create.
     */
    (billableItems: BillableItem[], options?: BulkCreateBillableItemsOptions | undefined): Promise<BulkCreateBillableItemsResponse>;
}
declare function bulkUpdateBillableItems$1(httpClient: HttpClient): BulkUpdateBillableItemsSignature;
interface BulkUpdateBillableItemsSignature {
    /**
     * Update multiple billable items.
     * @param - Billable items to update.
     */
    (billableItems: MaskedBillableItem[], options?: BulkUpdateBillableItemsOptions | undefined): Promise<BulkUpdateBillableItemsResponse>;
}
declare function bulkDeleteBillableItems$1(httpClient: HttpClient): BulkDeleteBillableItemsSignature;
interface BulkDeleteBillableItemsSignature {
    /**
     * Delete multiple billable items.
     * @param - Billable item IDs to delete.
     */
    (billableItemIds: string[]): Promise<BulkDeleteBillableItemsResponse>;
}
declare function bulkUpdateBillableItemTags$1(httpClient: HttpClient): BulkUpdateBillableItemTagsSignature;
interface BulkUpdateBillableItemTagsSignature {
    /**
     * Synchronously update tags on multiple billable items, by list of billable items IDs.
     * A tag that appears both in the list of assign and unassign tags, will be assigned.
     * @param - IDs of billable items which tags will be updated.
     */
    (billableItemIds: string[], options?: BulkUpdateBillableItemTagsOptions | undefined): Promise<V1BulkUpdateBillableItemTagsResponse>;
}
declare function bulkUpdateBillableItemTagsByFilter$1(httpClient: HttpClient): BulkUpdateBillableItemTagsByFilterSignature;
interface BulkUpdateBillableItemTagsByFilterSignature {
    /**
     * Asynchronously update tags on multiple billable items, by provided filter.
     * An empty filter will update all billable items.
     * A tag that appears both in the list of assign and unassign tags, will be assigned.
     * @param - Filter to select relevant billable items.
     */
    (filter: Record<string, any>, options?: BulkUpdateBillableItemTagsByFilterOptions | undefined): Promise<V1BulkUpdateBillableItemTagsByFilterResponse>;
}
declare function searchBillableItems$1(httpClient: HttpClient): SearchBillableItemsSignature;
interface SearchBillableItemsSignature {
    /**
     * Retrieves a list of up to 100 billable items, given the specified filtering, search expression, sorting, and cursor paging ([SDK](https://dev.wix.com/docs/sdk/articles/work-with-the-sdk/api-query-language) | [REST](https://dev.wix.com/api/rest/getting-started/api-query-language)).
     * @param - Search options.
     */
    (search: BillableItemSearch): Promise<SearchBillableItemsResponse>;
}
declare const onBillableItemCreated$1: EventDefinition<BillableItemCreatedEnvelope, "wix.billable_items.v1.billable_item_created">;
declare const onBillableItemDeleted$1: EventDefinition<BillableItemDeletedEnvelope, "wix.billable_items.v1.billable_item_deleted">;
declare const onBillableItemUpdated$1: EventDefinition<BillableItemUpdatedEnvelope, "wix.billable_items.v1.billable_item_updated">;

declare const createBillableItem: MaybeContext<BuildRESTFunction<typeof createBillableItem$1> & typeof createBillableItem$1>;
declare const getBillableItem: MaybeContext<BuildRESTFunction<typeof getBillableItem$1> & typeof getBillableItem$1>;
declare const updateBillableItem: MaybeContext<BuildRESTFunction<typeof updateBillableItem$1> & typeof updateBillableItem$1>;
declare const deleteBillableItem: MaybeContext<BuildRESTFunction<typeof deleteBillableItem$1> & typeof deleteBillableItem$1>;
declare const queryBillableItems: MaybeContext<BuildRESTFunction<typeof queryBillableItems$1> & typeof queryBillableItems$1>;
declare const bulkCreateBillableItems: MaybeContext<BuildRESTFunction<typeof bulkCreateBillableItems$1> & typeof bulkCreateBillableItems$1>;
declare const bulkUpdateBillableItems: MaybeContext<BuildRESTFunction<typeof bulkUpdateBillableItems$1> & typeof bulkUpdateBillableItems$1>;
declare const bulkDeleteBillableItems: MaybeContext<BuildRESTFunction<typeof bulkDeleteBillableItems$1> & typeof bulkDeleteBillableItems$1>;
declare const bulkUpdateBillableItemTags: MaybeContext<BuildRESTFunction<typeof bulkUpdateBillableItemTags$1> & typeof bulkUpdateBillableItemTags$1>;
declare const bulkUpdateBillableItemTagsByFilter: MaybeContext<BuildRESTFunction<typeof bulkUpdateBillableItemTagsByFilter$1> & typeof bulkUpdateBillableItemTagsByFilter$1>;
declare const searchBillableItems: MaybeContext<BuildRESTFunction<typeof searchBillableItems$1> & typeof searchBillableItems$1>;
/**
 * Triggered when a billable item is created.
 */
declare const onBillableItemCreated: BuildEventDefinition<typeof onBillableItemCreated$1>;
/**
 * Triggered when a billable item is deleted.
 */
declare const onBillableItemDeleted: BuildEventDefinition<typeof onBillableItemDeleted$1>;
/**
 * Triggered when a billable item is updated.
 */
declare const onBillableItemUpdated: BuildEventDefinition<typeof onBillableItemUpdated$1>;

export { BillableItem, BillableItemCreatedEnvelope, BillableItemDeletedEnvelope, BillableItemUpdatedEnvelope, BillableItemsQueryBuilder, BulkCreateBillableItemsOptions, BulkCreateBillableItemsResponse, BulkDeleteBillableItemsResponse, BulkUpdateBillableItemTagsByFilterOptions, BulkUpdateBillableItemTagsOptions, BulkUpdateBillableItemsOptions, BulkUpdateBillableItemsResponse, MaskedBillableItem, SearchBillableItemsResponse, UpdateBillableItem, V1BulkUpdateBillableItemTagsByFilterResponse, V1BulkUpdateBillableItemTagsResponse, bulkCreateBillableItems, bulkDeleteBillableItems, bulkUpdateBillableItemTags, bulkUpdateBillableItemTagsByFilter, bulkUpdateBillableItems, createBillableItem, deleteBillableItem, getBillableItem, onBillableItemCreated, onBillableItemDeleted, onBillableItemUpdated, queryBillableItems, searchBillableItems, updateBillableItem };
