// src/billable-items-v1-billable-item-billable-items.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { transformSDKFloatToRESTFloat } from "@wix/sdk-runtime/transformations/float";
import { transformRESTFloatToSDKFloat } from "@wix/sdk-runtime/transformations/float";
import { transformSDKTimestampToRESTTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformRESTTimestampToSDKTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformSDKFieldMaskToRESTFieldMask } from "@wix/sdk-runtime/transformations/field-mask";
import { transformPaths } from "@wix/sdk-runtime/transformations/transform-paths";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveWixBillableItemsV1BillableItemsUrl(opts) {
  const domainToMappings = {
    "manage._base_domain_": [
      {
        srcPath: "/_api/billable-items",
        destPath: ""
      }
    ],
    "www.wixapis.com": [
      {
        srcPath: "/billable-items/v1/billable-items",
        destPath: "/v1/billable-items"
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_get-paid_billable-items";
function createBillableItem(payload) {
  function __createBillableItem({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "billableItem.createdDate" },
          { path: "billableItem.updatedDate" }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.billable_items.v1.billable_item",
      method: "POST",
      methodFqn: "wix.billable_items.v1.BillableItems.CreateBillableItem",
      packageName: PACKAGE_NAME,
      url: resolveWixBillableItemsV1BillableItemsUrl({
        protoPath: "/v1/billable-items",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "billableItem.createdDate" },
            { path: "billableItem.updatedDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __createBillableItem;
}
function getBillableItem(payload) {
  function __getBillableItem({ host }) {
    const metadata = {
      entityFqdn: "wix.billable_items.v1.billable_item",
      method: "GET",
      methodFqn: "wix.billable_items.v1.BillableItems.GetBillableItem",
      packageName: PACKAGE_NAME,
      url: resolveWixBillableItemsV1BillableItemsUrl({
        protoPath: "/v1/billable-items/{billableItemId}",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "billableItem.createdDate" },
            { path: "billableItem.updatedDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __getBillableItem;
}
function updateBillableItem(payload) {
  function __updateBillableItem({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKFieldMaskToRESTFieldMask,
        paths: [{ path: "fieldMask" }]
      },
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "billableItem.createdDate" },
          { path: "billableItem.updatedDate" }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.billable_items.v1.billable_item",
      method: "PATCH",
      methodFqn: "wix.billable_items.v1.BillableItems.UpdateBillableItem",
      packageName: PACKAGE_NAME,
      url: resolveWixBillableItemsV1BillableItemsUrl({
        protoPath: "/v1/billable-items/{billableItem.id}",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "billableItem.createdDate" },
            { path: "billableItem.updatedDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __updateBillableItem;
}
function deleteBillableItem(payload) {
  function __deleteBillableItem({ host }) {
    const metadata = {
      entityFqdn: "wix.billable_items.v1.billable_item",
      method: "DELETE",
      methodFqn: "wix.billable_items.v1.BillableItems.DeleteBillableItem",
      packageName: PACKAGE_NAME,
      url: resolveWixBillableItemsV1BillableItemsUrl({
        protoPath: "/v1/billable-items/{billableItemId}",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload)
    };
    return metadata;
  }
  return __deleteBillableItem;
}
function queryBillableItems(payload) {
  function __queryBillableItems({ host }) {
    const metadata = {
      entityFqdn: "wix.billable_items.v1.billable_item",
      method: "POST",
      methodFqn: "wix.billable_items.v1.BillableItems.QueryBillableItems",
      packageName: PACKAGE_NAME,
      url: resolveWixBillableItemsV1BillableItemsUrl({
        protoPath: "/v1/billable-items/query",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "billableItems.createdDate" },
            { path: "billableItems.updatedDate" }
          ]
        }
      ]),
      fallback: [
        {
          method: "POST",
          url: resolveWixBillableItemsV1BillableItemsUrl({
            protoPath: "/v1/billable-items/query",
            data: payload,
            host
          }),
          data: payload
        }
      ]
    };
    return metadata;
  }
  return __queryBillableItems;
}
function bulkCreateBillableItems(payload) {
  function __bulkCreateBillableItems({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "billableItems.createdDate" },
          { path: "billableItems.updatedDate" }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.billable_items.v1.billable_item",
      method: "POST",
      methodFqn: "wix.billable_items.v1.BillableItems.BulkCreateBillableItems",
      packageName: PACKAGE_NAME,
      url: resolveWixBillableItemsV1BillableItemsUrl({
        protoPath: "/v1/bulk/billable-items/create",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "results.item.createdDate" },
            { path: "results.item.updatedDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __bulkCreateBillableItems;
}
function bulkUpdateBillableItems(payload) {
  function __bulkUpdateBillableItems({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKFieldMaskToRESTFieldMask,
        paths: [{ path: "billableItems.fieldMask" }]
      },
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "billableItems.billableItem.createdDate" },
          { path: "billableItems.billableItem.updatedDate" }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.billable_items.v1.billable_item",
      method: "POST",
      methodFqn: "wix.billable_items.v1.BillableItems.BulkUpdateBillableItems",
      packageName: PACKAGE_NAME,
      url: resolveWixBillableItemsV1BillableItemsUrl({
        protoPath: "/v1/bulk/billable-items/update",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "results.item.createdDate" },
            { path: "results.item.updatedDate" }
          ]
        }
      ])
    };
    return metadata;
  }
  return __bulkUpdateBillableItems;
}
function bulkDeleteBillableItems(payload) {
  function __bulkDeleteBillableItems({ host }) {
    const metadata = {
      entityFqdn: "wix.billable_items.v1.billable_item",
      method: "POST",
      methodFqn: "wix.billable_items.v1.BillableItems.BulkDeleteBillableItems",
      packageName: PACKAGE_NAME,
      url: resolveWixBillableItemsV1BillableItemsUrl({
        protoPath: "/v1/bulk/billable-items/delete",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __bulkDeleteBillableItems;
}
function bulkUpdateBillableItemTags(payload) {
  function __bulkUpdateBillableItemTags({ host }) {
    const metadata = {
      entityFqdn: "wix.billable_items.v1.billable_item",
      method: "POST",
      methodFqn: "wix.billable_items.v1.BillableItems.BulkUpdateBillableItemTags",
      packageName: PACKAGE_NAME,
      url: resolveWixBillableItemsV1BillableItemsUrl({
        protoPath: "/v1/bulk/billable-items/update-tags",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __bulkUpdateBillableItemTags;
}
function bulkUpdateBillableItemTagsByFilter(payload) {
  function __bulkUpdateBillableItemTagsByFilter({ host }) {
    const metadata = {
      entityFqdn: "wix.billable_items.v1.billable_item",
      method: "POST",
      methodFqn: "wix.billable_items.v1.BillableItems.BulkUpdateBillableItemTagsByFilter",
      packageName: PACKAGE_NAME,
      url: resolveWixBillableItemsV1BillableItemsUrl({
        protoPath: "/v1/bulk/billable-items/update-tags-by-filter",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __bulkUpdateBillableItemTagsByFilter;
}
function searchBillableItems(payload) {
  function __searchBillableItems({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKFloatToRESTFloat,
        paths: [
          { path: "search.aggregations.range.buckets.from" },
          { path: "search.aggregations.range.buckets.to" },
          {
            path: "search.aggregations.nested.nestedAggregations.range.buckets.from"
          },
          {
            path: "search.aggregations.nested.nestedAggregations.range.buckets.to"
          }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.billable_items.v1.billable_item",
      method: "POST",
      methodFqn: "wix.billable_items.v1.BillableItems.SearchBillableItems",
      packageName: PACKAGE_NAME,
      url: resolveWixBillableItemsV1BillableItemsUrl({
        protoPath: "/v1/billable-items/search",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "billableItems.createdDate" },
            { path: "billableItems.updatedDate" }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            { path: "aggregationData.results.ranges.results.from" },
            { path: "aggregationData.results.ranges.results.to" },
            {
              path: "aggregationData.results.groupedByValue.results.nestedResults.ranges.results.from"
            },
            {
              path: "aggregationData.results.groupedByValue.results.nestedResults.ranges.results.to"
            },
            {
              path: "aggregationData.results.nested.results.results.*.range.from"
            },
            {
              path: "aggregationData.results.nested.results.results.*.range.to"
            },
            { path: "aggregationData.results.scalar.value" },
            {
              path: "aggregationData.results.groupedByValue.results.nestedResults.scalar.value"
            },
            {
              path: "aggregationData.results.nested.results.results.*.scalar.value"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __searchBillableItems;
}

// src/billable-items-v1-billable-item-billable-items.meta.ts
function createBillableItem2() {
  const payload = {};
  const getRequestOptions = createBillableItem(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v1/billable-items",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function getBillableItem2() {
  const payload = { billableItemId: ":billableItemId" };
  const getRequestOptions = getBillableItem(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "GET",
    path: "/v1/billable-items/{billableItemId}",
    pathParams: { billableItemId: "billableItemId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function updateBillableItem2() {
  const payload = { billableItem: { id: ":billableItemId" } };
  const getRequestOptions = updateBillableItem(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "PATCH",
    path: "/v1/billable-items/{billableItem.id}",
    pathParams: { billableItemId: "billableItemId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function deleteBillableItem2() {
  const payload = { billableItemId: ":billableItemId" };
  const getRequestOptions = deleteBillableItem(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "DELETE",
    path: "/v1/billable-items/{billableItemId}",
    pathParams: { billableItemId: "billableItemId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function queryBillableItems2() {
  const payload = {};
  const getRequestOptions = queryBillableItems(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "GET",
    path: "/v1/billable-items/query",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function bulkCreateBillableItems2() {
  const payload = {};
  const getRequestOptions = bulkCreateBillableItems(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v1/bulk/billable-items/create",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function bulkUpdateBillableItems2() {
  const payload = {};
  const getRequestOptions = bulkUpdateBillableItems(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v1/bulk/billable-items/update",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function bulkDeleteBillableItems2() {
  const payload = {};
  const getRequestOptions = bulkDeleteBillableItems(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v1/bulk/billable-items/delete",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function bulkUpdateBillableItemTags2() {
  const payload = {};
  const getRequestOptions = bulkUpdateBillableItemTags(
    payload
  );
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v1/bulk/billable-items/update-tags",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function bulkUpdateBillableItemTagsByFilter2() {
  const payload = {};
  const getRequestOptions = bulkUpdateBillableItemTagsByFilter(
    payload
  );
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v1/bulk/billable-items/update-tags-by-filter",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function searchBillableItems2() {
  const payload = {};
  const getRequestOptions = searchBillableItems(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v1/billable-items/search",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
export {
  bulkCreateBillableItems2 as bulkCreateBillableItems,
  bulkDeleteBillableItems2 as bulkDeleteBillableItems,
  bulkUpdateBillableItemTags2 as bulkUpdateBillableItemTags,
  bulkUpdateBillableItemTagsByFilter2 as bulkUpdateBillableItemTagsByFilter,
  bulkUpdateBillableItems2 as bulkUpdateBillableItems,
  createBillableItem2 as createBillableItem,
  deleteBillableItem2 as deleteBillableItem,
  getBillableItem2 as getBillableItem,
  queryBillableItems2 as queryBillableItems,
  searchBillableItems2 as searchBillableItems,
  updateBillableItem2 as updateBillableItem
};
//# sourceMappingURL=meta.mjs.map